"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isUnchangedLine = exports.isDeletionLine = exports.isAdditionLine = exports.isChunkHeader = exports.isDeleteMarkerLine = exports.isAddMarkerLine = exports.isMetaDataLine = exports.isComparisonInputLine = void 0;
/**
 * Checks whether a line is a comparison input line or not.
 * @param {string} line The line to check.
 * @returns {boolean} Returns `true` if the given line is a comparison line, otherwise `false`.
 * @example
 * // comparison input line.
 * "diff --git a/file.txt b/file.txt"
 */
function isComparisonInputLine(line) {
    const [diff, doubleDashGit, fileA, fileB, rest] = line.split(' ');
    return !!(diff === 'diff' &&
        doubleDashGit === '--git' &&
        fileA &&
        fileB &&
        !rest);
}
exports.isComparisonInputLine = isComparisonInputLine;
/**
 * Checks whether a line is a meta data line or not.
 * @param line The line to check.
 * @returns {boolean} Return `true` if the given line is a meta data line, otherwise `false`.
 * @example
 * // meta data line.
 * "index 6b0c6cf..b37e70a 100644"
 */
function isMetaDataLine(line) {
    return /^index/.test(line);
}
exports.isMetaDataLine = isMetaDataLine;
function isAddMarkerLine(line) {
    return /^\+\+\+\s/.test(line);
}
exports.isAddMarkerLine = isAddMarkerLine;
function isDeleteMarkerLine(line) {
    return /^\-\-\-\s/.test(line);
}
exports.isDeleteMarkerLine = isDeleteMarkerLine;
/**
 * Checks whether the line is a chunk header or not
 * @param line The line to check.
 * @returns return `true` if the given line is a chunk header, otherwise `false`.
 * @example
 * // start line of diff chunks
 * "@@ -1 +1 @@ describe('utils', () => {..."
 * "@@ -23,15 +23,15 @@ describe('utils', () => { ..."
 */
function isChunkHeader(line) {
    return /^@@\s\-\d+(,\d+)?\s\+\d+(,\d+)?\s@@\s?/.test(line);
} // test
exports.isChunkHeader = isChunkHeader;
/**
 * Checks whether the line is an addition line.
 * @param {string} line The line to check.
 * @returns {boolean} Return `true` if the given line is an addition line, otherwise `false`.
 */
function isAdditionLine(line) {
    return line[0] === '+';
}
exports.isAdditionLine = isAdditionLine;
/**
 * Checks whether the line is an deletion line.
 * @param {string} line The line to check.
 * @returns {boolean} Return `true` if the given line is an deletion line, otherwise `false`.
 */
function isDeletionLine(line) {
    return line[0] === '-';
}
exports.isDeletionLine = isDeletionLine;
function isUnchangedLine(line) {
    return line[0] === ' ';
}
exports.isUnchangedLine = isUnchangedLine;
